Thank you for downloading wger Workout Manager. Workout Manager is a free, open
source web application that manages your exercises, workouts, weight and diet
plans.

For more details and a live system, refer to the project's site: http://wger.de/


Sources
-------

All the code and the content is freely available:

* **Main repository**: HG, https://bitbucket.org/rolandgeider/workout_manager
* **Mirror**: GIT, https://github.com/rolandgeider/workout_manager


Contact
-------

Feel free to write me an email (``roland @ NO!SPAM! geider.net``) if you found
this useful or if there was something that didn't behave as you expected.
Alternatively, you can also open a ticket on the bitbucket tracker:
https://bitbucket.org/rolandgeider/workout_manager/issues



Installation
------------

This is a Django application, so if you know how to install one, you can instal
this one. There are more detailed instructions on http://wger.de/en/software/code


Licence
-------

The application is licenced under the Affero GNU General Public License 3 or later
(AGPL 3+).

The initial exercise and ingredient data is licensed additionally under a
Creative Commons Attribution Share-Alike 3.0 (CC-BY-SA 3.0)

The YAML CSS framework is licensed under a Creative Commons Attribution 2.0
License (CC-BY 2.0)

Some images where taken from Wikipedia, see the SOURCES file in their respective
folders for more details.
